/*
 * Copyright (C) 2016 Christopher Batey and Dogan Narinc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package common;

public class CassandraQuery {
    private final String query;
    private final QueryType queryType;
    private final Object[] variables;

    public CassandraQuery(String query) {
        this(query, new Object[] {});
    }

    public CassandraQuery(String query, Object... variables) {
        this(query, QueryType.QUERY, variables);
    }

    public CassandraQuery(String query, QueryType queryType, Object... variables) {
        this.query = query;
        this.queryType = queryType;
        this.variables = variables;
    }

    public String getQuery() {
        return query;
    }

    public Object[] getVariables() {
        return variables;
    }

    public QueryType getQueryType() {
        return queryType;
    }

    public enum QueryType {
        QUERY, PREPARED_STATEMENT
    }
}
